!!! warning

    This page is redundant with the unified docs in `biocypher/documentation`.
    Community docs will be maintained there.

# How to Start Contributing

There are many valuable ways to contribute besides writing code. Thank you for
dedicating your time to improve our projects!

## :octicons-issue-opened-24:{ .lg .middle } Bug reports and enhancement requests

Bug reports and enhancement requests are an important part of making any
software more stable. We curate them though Github issues. When opening an
issue or request, please select the appropriate category and fill out the issue
form fully to ensure others and the core development team can fully understand
the scope of the issue. If your category is not listed, you can create a blank
issue.

The issue will then show up to the BioCypher community and be open to
comments/ideas from others.

### Categories

- [Bug Report](https://github.com/biocypher/biocypher/issues/new?template=BUG-REPORT.yml): Report incorrect behavior in the BioCypher library
- [Register New Component](https://github.com/biocypher/biocypher/issues/new?template=ADD-COMPONENT.yml): Register a new component in the BioCypher ecosystem, either one you have created, or one that you would like to see added
- Documentation Improvement: Report wrong or missing documentation
- Feature Request: Suggest an idea for BioCypher

## :octicons-checklist-24:{ .lg .middle } Detailed Guides

<div class="grid cards" markdown>

-   :octicons-book-24:{ .lg .middle } __Contributing to the Documentation__

    ---

    A simple way to get started is to contribute to the documentation. Please
    follow the guide [here](./contribute-docs.md) to learn how to do so.

    [:octicons-arrow-right-24: To the contribution guide](./contribute-docs.md)

</div>

<div class="grid cards" markdown>

-   :octicons-code-24:{ .lg .middle } __Contributing to the Code Base__

    ---

    The best way to contribute code is to open a pull request on Github. Please
    follow the guide [here](./contribute-codebase.md) to learn how to do so.

    [:octicons-arrow-right-24: To the contribution guide](./contribute-codebase.md)

</div>
